==> apache-ignite-2.7.0-bin.zip: apache-ignite-2.7.0-bin/platforms/cpp/docs/search/all_b.js <==
var searchData=
[
  ['makeconstreference',['MakeConstReference',['../namespaceignite.html#ae78424fdffadc92e84b815d5df9c6fee',1,'ignite::MakeConstReference(const T &amp;val)'],['../namespaceignite.html#ae937deaf9a618b1441ad3e49c76f4b8d',1,'ignite::MakeConstReference(const T *val)']]],
  ['makeconstreferencefromcopy',['MakeConstReferenceFromCopy',['../namespaceignite.html#a713b8934e0021d44b99f15acae86efe2',1,'ignite']]],
  ['makeconstreferencefromowningpointer',['MakeConstReferenceFromOwningPointer',['../namespaceignite.html#a6b46914ac275250143be90e5bc2411e2',1,'ignite']]],
  ['makeconstreferencefromsmartpointer',['MakeConstReferenceFromSmartPointer',['../namespaceignite.html#a4d056cf27c881af6b06bda130d0f64ed',1,'ignite']]],
  ['makereference',['MakeReference',['../namespaceignite.html#a55790b7e48e45cd757e7d34aacc4357a',1,'ignite::MakeReference(T &amp;val)'],['../namespaceignite.html#ac1523106a14156cf653b3366d92562cd',1,'ignite::MakeReference(T *val)']]],
  ['makereferencefromcopy',['MakeReferenceFromCopy',['../namespaceignite.html#a1876725dc2d3119c5a0b15cf417aa1d0',1,'ignite']]],
  ['makereferencefromowningpointer',['MakeReferenceFromOwningPointer',['../namespaceignite.html#a700a57aef7b1a3ebd13feed33dcf4170',1,'ignite']]],
  ['makereferencefromsmartpointer',['MakeReferenceFromSmartPointer',['../namespaceignite.html#a01845a228a65220aed4fa281e408c610',1,'ignite']]],
  ['maptype',['MapType',['../structignite_1_1binary_1_1MapType.html',1,'ignite::binary']]],
  ['marked_5frollback',['MARKED_ROLLBACK',['../structignite_1_1transactions_1_1TransactionState.html#a173faba612c6a4e91c0726140d8d43f3ae82d9c2d38f1a1a3525ad13fab1ec06b',1,'ignite::transactions::TransactionState']]],
  ['mutable_5fcache_5fentry_2eh',['mutable_cache_entry.h',['../mutable__cache__entry_8h.html',1,'']]],
  ['mutablecacheentry',['MutableCacheEntry',['../classignite_1_1cache_1_1MutableCacheEntry.html',1,'ignite::cache']]],
  ['mutablecacheentry',['MutableCacheEntry',['../classignite_1_1cache_1_1MutableCacheEntry.html#a34eb9d25b6f61ba2e330efcccb3d9a5d',1,'ignite::cache::MutableCacheEntry::MutableCacheEntry()'],['../classignite_1_1cache_1_1MutableCacheEntry.html#a3428e92459fd3bd70f32f9a6e1a0c011',1,'ignite::cache::MutableCacheEntry::MutableCacheEntry(const K &amp;key)'],['../classignite_1_1cache_1_1MutableCacheEntry.html#a974701d5dedc7f34ad34a9f35e37124a',1,'ignite::cache::MutableCacheEntry::MutableCacheEntry(const K &amp;key, const V &amp;val)'],['../classignite_1_1cache_1_1MutableCacheEntry.html#a86cc3887dac064befa71d3d97f69a760',1,'ignite::cache::MutableCacheEntry::MutableCacheEntry(const MutableCacheEntry &amp;other)']]]
];

==> apache-ignite-2.7.5-bin.zip: apache-ignite-2.7.5-bin/platforms/cpp/docs/search/all_b.js <==
var searchData=
[
  ['makeconstreference',['MakeConstReference',['../namespaceignite.html#ae78424fdffadc92e84b815d5df9c6fee',1,'ignite::MakeConstReference(const T &amp;val)'],['../namespaceignite.html#ae937deaf9a618b1441ad3e49c76f4b8d',1,'ignite::MakeConstReference(const T *val)']]],
  ['makeconstreferencefromcopy',['MakeConstReferenceFromCopy',['../namespaceignite.html#a713b8934e0021d44b99f15acae86efe2',1,'ignite']]],
  ['makeconstreferencefromowningpointer',['MakeConstReferenceFromOwningPointer',['../namespaceignite.html#a6b46914ac275250143be90e5bc2411e2',1,'ignite']]],
  ['makeconstreferencefromsmartpointer',['MakeConstReferenceFromSmartPointer',['../namespaceignite.html#a4d056cf27c881af6b06bda130d0f64ed',1,'ignite']]],
  ['makereference',['MakeReference',['../namespaceignite.html#a55790b7e48e45cd757e7d34aacc4357a',1,'ignite::MakeReference(T &amp;val)'],['../namespaceignite.html#ac1523106a14156cf653b3366d92562cd',1,'ignite::MakeReference(T *val)']]],
  ['makereferencefromcopy',['MakeReferenceFromCopy',['../namespaceignite.html#a1876725dc2d3119c5a0b15cf417aa1d0',1,'ignite']]],
  ['makereferencefromowningpointer',['MakeReferenceFromOwningPointer',['../namespaceignite.html#a700a57aef7b1a3ebd13feed33dcf4170',1,'ignite']]],
  ['makereferencefromsmartpointer',['MakeReferenceFromSmartPointer',['../namespaceignite.html#a01845a228a65220aed4fa281e408c610',1,'ignite']]],
  ['maptype',['MapType',['../structignite_1_1binary_1_1MapType.html',1,'ignite::binary']]],
  ['marked_5frollback',['MARKED_ROLLBACK',['../structignite_1_1transactions_1_1TransactionState.html#a173faba612c6a4e91c0726140d8d43f3ae82d9c2d38f1a1a3525ad13fab1ec06b',1,'ignite::transactions::TransactionState']]],
  ['mutable_5fcache_5fentry_2eh',['mutable_cache_entry.h',['../mutable__cache__entry_8h.html',1,'']]],
  ['mutablecacheentry',['MutableCacheEntry',['../classignite_1_1cache_1_1MutableCacheEntry.html',1,'ignite::cache::MutableCacheEntry&lt; K, V &gt;'],['../classignite_1_1cache_1_1MutableCacheEntry.html#a34eb9d25b6f61ba2e330efcccb3d9a5d',1,'ignite::cache::MutableCacheEntry::MutableCacheEntry()'],['../classignite_1_1cache_1_1MutableCacheEntry.html#a3428e92459fd3bd70f32f9a6e1a0c011',1,'ignite::cache::MutableCacheEntry::MutableCacheEntry(const K &amp;key)'],['../classignite_1_1cache_1_1MutableCacheEntry.html#a974701d5dedc7f34ad34a9f35e37124a',1,'ignite::cache::MutableCacheEntry::MutableCacheEntry(const K &amp;key, const V &amp;val)'],['../classignite_1_1cache_1_1MutableCacheEntry.html#a86cc3887dac064befa71d3d97f69a760',1,'ignite::cache::MutableCacheEntry::MutableCacheEntry(const MutableCacheEntry &amp;other)']]]
];
